@@ -14,6 +14,14 @@ def conditional_expression(expression):
     true_value = expression_list[1].split(" : ")[0]
     false_value = expression_list[1].split(" : ")[1]
     new_expression = '%s if %s else %s' % (true_value, condition, false_value)
+    try:
+        eval(true_value)
+    except:
+        true_value = f'"{true_value}"'
+    try:
+        eval(false_value)
+    except:
+        false_value = f'"{false_value}"'
     try:
         response = eval(new_expression)
         return response, True
